@@ -36,7 +36,40 @@ use base qw{ PPIx::Regexp::Structure };
 
 use PPIx::Regexp::Constant qw{ @CARP_NOT };
 
-our $VERSION = '0.071';
+our $VERSION = '0.078';
+
+sub __new {
+    my ( $class, $content, %arg ) = @_;
+
+    my $self = $class->SUPER::__new( $content, %arg );
+
+    defined $arg{error}
+	and $self->{explanation} = $self->{error} = $arg{error};
+
+    defined $arg{explanation}
+	and $self->{explanation} = $arg{explanation};
+
+    return $self;
+}
+
+sub explain {
+    my ( $self ) = @_;
+    return $self->{explanation} || $self->SUPER::explain();
+}
+
+sub __PPIX_ELEM__rebless {
+    my ( $class, $self, %arg ) = @_;
+    my $rslt = $class->SUPER::__PPIX_ELEM__rebless( $self, %arg );
+    unless ( defined( $self->{error} = $arg{error} ) ) {
+	Carp::cluck( 'Making unknown token with no error message' );
+	$self->{error} = 'Unspecified error';
+	$rslt++;
+    }
+    $self->{explanation} = defined $arg{explanation} ?
+	$arg{explanation} :
+	$arg{error};
+    return $rslt;
+}
 
 1;
 
@@ -45,7 +78,8 @@ __END__
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org>, or in electronic mail to the author.
+L<https://github.com/trwyant/perl-PPIx-Regexp/issues>, or in electronic
+mail to the author.
 
 =head1 AUTHOR
 
@@ -53,7 +87,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2020 by Thomas R. Wyant, III
+Copyright (C) 2009-2021 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
